@@ -15,7 +15,8 @@ BEGIN {
     @EXPORT_OK = qw(
 	calc_geom 
 	check_file 
-    get_pdb_path_fh
+	exist_pdb_code_on_obsoletes 
+	exist_pdb_code_on_uncompressed 
 	get_full_path_name_for_pdb_code 
 	get_from_file 
 	translate 
@@ -52,6 +53,7 @@ BEGIN {
 	findo 
 	pointsonsphere 
 	norm2 
+    get_pdb_path_fh
     );
 
     @EXPORT = qw(
@@ -65,7 +67,6 @@ use Storable qw(dclone);
 use Carp;
 use IO::Uncompress::Gunzip qw(gunzip);
 use File::Spec::Functions qw(catfile);
-use File::Find::Rule;
 
 use Config::Simple;
 # accessing a block of an ini-file;
@@ -81,15 +82,14 @@ my $host = "";
 
 =head1 NAME
 
-GeometricalCalculations - The great new GeometricalCalculations!
+GeometricalCalculations 
 
 =head1 VERSION
 
-Version 0.01
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.05';
 
 
 =head1 SYNOPSIS
@@ -169,11 +169,10 @@ sub check_file {
 
 =head2 _getReadingFileHandle
 	
-    subroutine to get a reading file handle for a file.
-    input : full path name
-    output: file handler 
-   
-    die on error
+    subroutine to get a reading file handle
+        for a file.
+
+        input: file path name to the file 
 =cut
 
 sub _getReadingFileHandle {
@@ -193,6 +192,136 @@ sub _getReadingFileHandle {
     return $fh;
 }
 
+=head2 exist_pdb_code_on_obsoletes
+	check if a four-letters pdb code exist in PDB obsoletes folder
+	it will return the full path name if a match is found.
+	return undef if not file was found
+	
+        exist_pdb_code_on_obsoletes
+	input  : pdb_code (4fab)
+	return : full path name
+
+=cut
+
+sub exist_pdb_code_on_obsoletes {
+    use File::Spec::Functions qw(catfile);
+    
+    my ($pdb_code) = @_;
+    croak "exist_pdb_code_on_obsoletes: pdb_code is required" 
+        unless $pdb_code;
+
+    chomp $pdb_code;
+    croak "$pdb_code does not look like a four-letter PDB_CODE"
+      unless $pdb_code =~ /[A-z0-9]{4}/;
+
+    my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
+    my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
+
+    # my $uncompressed = "$PDB_PATH/obsoletes/$pdb_file_name";
+    # my $compressed   = "$PDB_PATH/obsoletes/$pdb_file_name_gz";
+    my $uncompressed = catfile($PDB_PATH, 'obsoletes', $pdb_file_name);
+    my $compressed   = catfile($PDB_PATH, 'obsoletes', $pdb_file_name_gz);
+
+    # try uncompressed pdb filename existence
+    if ( -e $uncompressed ) {
+        return $uncompressed;
+    }
+
+    # try compressed file
+    elsif ( -e $compressed ) {
+        return $compressed;
+    }
+    else {
+        return undef;
+    }
+}
+
+=head2 exist_pdb_code_on_uncompressed
+
+	check if a four-letters pdb code exist in uncompressed PDB folder
+	it will return the full path name if a match is found.
+	Return undef if not file was found
+	
+        input  : pdb_code (4fab)
+	return : full path name
+
+=cut
+
+sub exist_pdb_code_on_uncompressed {
+    use File::Spec::Functions qw(catfile);
+
+    my ($pdb_code) = @_;
+    croak "exist_pdb_code_on_uncompressed: pdb_code is required" 
+        unless $pdb_code;
+
+    chomp $pdb_code;
+    croak "$pdb_code does not look like a four-letter PDB_CODE"
+      unless $pdb_code =~ /[A-z0-9]{4}/;
+
+    my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
+    my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
+
+    # my $uncompressed = "$PDB_PATH/uncompressed/$pdb_file_name";
+    # my $compressed   = "$PDB_PATH/uncompressed/$pdb_file_name_gz";
+    my $uncompressed = catfile($PDB_PATH, 'uncompressed', $pdb_file_name);
+    my $compressed   = catfile($PDB_PATH, 'uncompressed', $pdb_file_name_gz);
+
+    # try uncompressed pdb filename existence
+    if ( -e $uncompressed ) {
+        return $uncompressed;
+    }
+
+    # try compressed file
+    elsif ( -e $compressed ) {
+        return $compressed;
+    }
+    else {
+        return undef;
+    }
+}
+
+=head2 exist_pdb_code_on_alternate
+
+	check if a four-letters pdb code exist in user defined alternate 
+	PDB folder
+        it will return the full path name if a match is found.
+	Return undef if not file was found
+	
+        input  : pdb_code (4fab)
+	return : full path name
+
+=cut
+
+sub exist_pdb_code_on_alternate { 
+    my ($pdb_code) = @_;
+    croak "exist_pdb_code_on_alternate: pdb_code is required" 
+        unless $pdb_code;
+
+    chomp $pdb_code;
+    croak "$pdb_code does not look like a four-letter PDB_CODE"
+      unless $pdb_code =~ /[A-z0-9]{4}/;
+
+    my $pdb_file_name    = "pdb" . $pdb_code . '.ent';
+    my $pdb_file_name_gz = "pdb" . $pdb_code . '.ent.gz';
+
+    # my $uncompressed = "$USER_SPECIFIC_PDB_PATH/$pdb_file_name";
+    # my $compressed   = "$USER_SPECIFIC_PDB_PATH/$pdb_file_name_gz";
+    my $uncompressed = catfile($USER_SPECIFIC_PDB_PATH, $pdb_file_name);
+    my $compressed   = catfile($USER_SPECIFIC_PDB_PATH, $pdb_file_name_gz);
+
+    # try uncompressed pdb filename existence
+    if ( -e $uncompressed ) {
+        return $uncompressed;
+    }
+
+    # try compressed file
+    elsif ( -e $compressed ) {
+        return $compressed;
+    }
+    else {
+        return undef;
+    }
+}
 
 =head2 get_full_path_name_for_pdb_code
 	Return a fullpath name for a given four-letter PDB code	
@@ -204,8 +333,6 @@ sub _getReadingFileHandle {
 
 sub get_full_path_name_for_pdb_code {
     use Data::Dumper;
-    use File::Find::Rule;
-
     my ($pdb_code) = @_;
    
     if ($DEBUG){
@@ -224,71 +351,20 @@ sub get_full_path_name_for_pdb_code {
     croak "$pdb_code does not look like a four-letter PDB_CODE"
       unless $pdb_code =~ /[A-z0-9]{4}/;
 
-    my $rule =  File::Find::Rule->new;
-    $rule->file;
-    
-    $rule->name( qr/$pdb_code/ );
-    
-    my @file_full_path = $rule->in($PDB_PATH);
-    
-    if ( @file_full_path > 1 ){
-	    my  ($package, $filename, $line) = caller;
-        
-        my $dump= print Dumper(\@file_full_path);
-        my $str = qq{
-        function: get_full_path_name_for_pdb_code
-        package  = $package
-	    filename = $filename
-	    line     = $line\n";
-        
-        I DO NOT KNOW WHO TO PROCEED!
-        I FOUND MORE THAN ONE PDB FILE FOR $pdb_code
-        IN: 
-            PDB_PATH = $PDB_PATH
-            USER_SPECIFIC_PDB_PATH = $USER_SPECIFIC_PDB_PATH
-        
-        THIS IS WHAT I FOUND:   
-        "@file_full_path"
-        };
-        $str = $str. $dump;
-        croak "$str";
-    }
-    
-    return $file_full_path[0] if @file_full_path;
+    my $path;
+    $path = exist_pdb_code_on_uncompressed($pdb_code);
+    return $path if $path;
 
-    unless (@file_full_path) {
-        @file_full_path = $rule->in($USER_SPECIFIC_PDB_PATH);
-        
-        if ( @file_full_path > 1 ){
-            my  ($package, $filename, $line) = caller;
-            
-            my $dump= print Dumper(\@file_full_path);
-            my $str = qq{
-            function: get_full_path_name_for_pdb_code
-            package  = $package
-            filename = $filename
-            line     = $line\n";
-            
-            I DO NOT KNOW WHO TO PROCEED!
-            I FOUND MORE THAN ONE PDB FILE FOR $pdb_code
-            IN: 
-                PDB_PATH = $PDB_PATH
-                USER_SPECIFIC_PDB_PATH = $USER_SPECIFIC_PDB_PATH
-            
-            THIS IS WHAT I FOUND:   
-            "@file_full_path"
-            };
-            $str = $str. $dump;
-            croak "$str";
-        }
-        return $file_full_path[0] if @file_full_path;
-    }
+    $path = exist_pdb_code_on_obsoletes($pdb_code);
+    return $path if $path;
+    
+    $path = exist_pdb_code_on_alternate($pdb_code);
+    return $path if $path;
 
     croak "Could not find $pdb_code on $PDB_PATH/obsoletes, $PDB_PATH/uncompressed or $USER_SPECIFIC_PDB_PATH"
-      unless $file_full_path[0];
+      unless $path;
 }
 
-
 =head2 get_from_file
 
 	subroutine to read PDB file and obtain coordinates of backbone atoms.
@@ -311,9 +387,49 @@ sub get_full_path_name_for_pdb_code {
 
 
 =cut
+sub get_pdb_path_fh  {
+    # data contains pdbid, chain, start, ss1, ss2
+    use Data::Dumper;
+    use File::Basename;
+    #print Dumper($data);
+    
+    my ( $data ) = @_;
+    die "get_pdb_path_fh required array" unless @$data;
+   
 
+    # print Dumper(\$data);
+    # $$data[0] has values like this:
+    # 2kl8/pdb2kl8.ent
+    my $pdb_code;
+     
+    print "Looking for data[0] = $$data[0]\n" if $DEBUG;
+    if ( $$data[0] =~ /\// ) {
+        my $filename = basename $$data[0];
+        if ( $filename =~ /pdb(\w{4}).*/ ) {
+            $pdb_code =  $1;
+        } 
+        elsif ( $filename =~ /(\w{4}).*/ ) {
+            $pdb_code =  $1;
+        }
+        else {} 
+    }
+    else {
+        $pdb_code = $$data[0];
+        $pdb_code =~ s/^pdb//g;     # removing leading pdb string
+        $pdb_code =~ s/\.(\w+)$//g; # removing file extension
+    }
+    die "Could not extract pdb_code_id from $$data[0]" unless $pdb_code;
 
-sub get_from_file {
+    my $full_path_name = get_full_path_name_for_pdb_code($pdb_code);
+    
+    die "get_pdb_path_fh: Could not find path for $pdb_code" 
+        unless $full_path_name;
+    
+    return $full_path_name; 
+}
+
+sub get_from_file_old {
+# sub get_from_file {
     my ( $data, $landmarks, $string, $seq, $fh ) = @_;
 
     # data contains pdbid, chain, start, ss1, ss2
@@ -422,33 +538,28 @@ sub get_from_file {
     return @coords;
 }
 
-=head2 get_pdb_path_fh
-	
-	it will return the full path name for a pdb_code_id 
-    if a match is found in PDB folder.
-	die if not file was found
-     
-	input  : vilas (@array)
-	return : full path name
-
-=cut
-
-sub get_pdb_path_fh  {
+sub get_from_file {
     
+    my ( $data, $landmarks, $string, $seq ) = @_;
+
     # data contains pdbid, chain, start, ss1, ss2
     use Data::Dumper;
     use File::Basename;
-    
-    my ( $data ) = @_;
-    die "get_pdb_path_fh required array" unless @$data;
-   
-    # print Dumper(\$data);
+    #print Dumper($data);
+
+    my $chain    = $$data[1];
+    my $startres = $$data[2];
+    my $endres   = $$data[2] + $$data[5] + $$data[3] + $$data[4] - 1;
+    @$landmarks =
+      ( $$data[3], $$data[3] + $$data[5], $$data[3] + $$data[5] + $$data[4] );
+
     # $$data[0] has values like this:
     # 2kl8/pdb2kl8.ent
     my $pdb_code;
      
     print "Looking for data[0] = $$data[0]\n" if $DEBUG;
     if ( $$data[0] =~ /\// ) {
+        # $pdb_code = ( split( /\//, $$data[0] ) )[0];
         my $filename = basename $$data[0];
         if ( $filename =~ /pdb(\w{4}).*/ ) {
             $pdb_code =  $1;
@@ -463,15 +574,106 @@ sub get_pdb_path_fh  {
         $pdb_code =~ s/^pdb//g;     # removing leading pdb string
         $pdb_code =~ s/\.(\w+)$//g; # removing file extension
     }
-    die "Could not extract pdb_code_id from $$data[0]" 
-        unless $pdb_code;
-
+    
+    #unless ( $$data[0] ) {
+    #   use Data::Dumper;
+    #   print "pdb_code $pdb_code\n";
+    #   print Dumper($data);
+    #   #croak "get_from_file: pdb_code is required";
+    #}
     my $full_path_name = get_full_path_name_for_pdb_code($pdb_code);
-    
-    die "get_pdb_path_fh: Could not find path for $pdb_code" 
-        unless $full_path_name;
-    
-    return $full_path_name; 
+    my $fh             = _getReadingFileHandle($full_path_name);
+
+    my $done    = 0;
+    my @coords  = ();
+    my $prevres = 0;
+    my $len     = length($string);
+    my $id      = $prevres;
+    if ( $string ne 'CB' )
+    { #certain residues (GLY) will not have CBs, so this case has to be treated separately
+        while ( defined( my $line = <$fh> ) and ( $done == 0 ) ) {
+            chomp($line);
+            if ( $line =~
+                /ATOM\s+-*\d+\s+$string\s+(\w+)\s$chain\s*(-*\d+\w?\s)/ )
+            {
+                $id = $2;
+                my $amino = $1;
+                if ( $id =~ /(-*\d+)\D/ ) { $id = $1 }
+                if ( $id ne $prevres ) {
+                    if ( $id > $endres ) {
+                        $done = 1;
+                    }
+                    elsif ( $id >= $startres ) {
+                        push(
+                            @coords,
+                            [
+                                substr( $line, 30, 8 ),
+                                substr( $line, 38, 8 ),
+                                substr( $line, 46, 8 )
+                            ]
+                        );
+
+                        #print "$line\t$amino\n";
+                        $$seq = $$seq . translate($amino);
+
+                        #print "$line\n";
+                    }
+                }
+                $prevres = $id;
+            }
+        }
+    }
+    else {
+        $$seq = '';
+        my $prevline = <$fh>;
+        while ( defined( my $line = <$fh> ) and ( $done == 0 ) ) {
+            chomp($line);
+            if ( $line =~ /ATOM\s+-*\d+\s+CB\s+(\w+)\s$chain\s*(-*\d+\w?\s)/ ) {
+                $id = $2;
+                my $amin = substr( $1, -3, 3 );
+                if ( $id =~ /(-*\d+)\D/ ) { $id = $1 }
+                if ( $id ne $prevres ) {
+                    if ( $id > $endres ) {
+                        $done = 1;
+                    }
+                    elsif ( $id >= $startres ) {
+                        push(
+                            @coords,
+                            [
+                                substr( $line, 30, 8 ),
+                                substr( $line, 38, 8 ),
+                                substr( $line, 46, 8 )
+                            ]
+                        );
+                        $$seq = $$seq . translate($amin);
+
+                        #print "$line\t$startres\t$endres\n";
+                    }
+                }
+                $prevres = $id;
+            }
+            elsif (
+                $prevline =~ /ATOM\s+-*\d+\s+O\s+(\w+)\s$chain\s*(-*\d+\w?\s)/ )
+            {
+                $id = $2;
+                my $amin = substr( $1, -3, 3 );
+                if ( $id =~ /(-*\d+)\D/ ) { $id = $1 }
+                if ( $id ne $prevres ) {
+                    if ( $id > $endres ) {
+                        $done = 1;
+                    }
+                    elsif ( $id >= $startres ) {
+                        push( @coords, 0 );
+                        $$seq = $$seq . translate($amin);
+                    }
+                }
+                $prevres = $id;
+            }
+            $prevline = $line;
+        }
+    }
+    close($fh);
+    return @coords;
 }
 
 =head2 translate2
