@@ -16,7 +16,7 @@ Protein Class
 
 =head1 VERSION
 
-Version 0.01
+Version 0.05
 
 =head1 SYNOPSIS
 
@@ -338,33 +338,11 @@ sub add_motif_from_file {
 
 	}
     # print "start get_from_file\n";
-	my $fpath = SmotifCS::GeometricalCalculations::get_pdb_path_fh(\@idtable);
-    my $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-    my @ca = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'CA', \$seq, $fh);
-    close $fh;
-
-    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-    my @n  = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'N' , \$seq, $fh);
-    close $fh;
-    
-    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-	my @c  = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'C' , \$seq, $fh);
-    close $fh;
-    
-    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-	my @cb = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'CB', \$seq, $fh);
-    close $fh;
-    
-    $fh    = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-	my @o  = SmotifCS::GeometricalCalculations::get_from_file( \@idtable, \@lm, 'O' , \$seq, $fh);
-    close $fh;
-=for	
     my @ca = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
 	my @n  = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq);
 	my @c  = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq);
 	my @cb = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq);
 	my @o  = SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq);
-=cut    
     # print scalar(@ca),"\t",scalar(@n),"\t",scalar(@c),"\t",scalar(@cb),"\t",scalar(@o),"\n";
 	#look for missing cb atoms (from glycines)
 	for (my $aa=0;$aa<scalar(@cb);$aa++) {
@@ -419,33 +397,11 @@ sub add_partial_motif {
 		# GeometricalCalculations::getnid(\@proptable, \@idtable);
 		SmotifCS::MYSQLSmotifs::getnid(\@proptable, \@idtable);
 	}
-    my $fpath = SmotifCS::GeometricalCalculations::get_pdb_path_fh(\@idtable);
-    my $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-	my @ca=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq, $fh);
-    close $fh;
-	
-    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-    my @n=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq, $fh);
-    close $fh;
-	
-    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-    my @c=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq, $fh);
-    close $fh;
-	
-    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-    my @cb=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq, $fh);
-    close $fh;
-	
-    $fh = SmotifCS::GeometricalCalculations::_getReadingFileHandle($fpath);
-    my @o=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq, $fh);
-    close $fh;
-=for	
     my @ca=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CA',\$seq);
 	my @n=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'N',\$seq);
 	my @c=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'C',\$seq);
 	my @cb=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'CB',\$seq);
 	my @o=SmotifCS::GeometricalCalculations::get_from_file(\@idtable,\@lm,'O',\$seq);
-=cut
 	# generate missing C-beta atoms for glycine residues
 	for (my $aa=0;$aa<scalar(@cb);$aa++) {
 		if ($cb[$aa]==0) {
